layoutSeed property
The random seed used for the initial layout generation. Set this dynamically per search to ensure unique graph positions.
Implementation
final int layoutSeed;
The random seed used for the initial layout generation. Set this dynamically per search to ensure unique graph positions.
final int layoutSeed;