GraphEdge class

Represents an edge (relationship) between two nodes.

Constructors

GraphEdge({required String sourceId, required String targetId, String? label, bool isDashed = false, Color? color})
const

Properties

color Color?
Optional custom color for this specific edge.
final
hashCode int
The hash code for this object.
no setterinherited
isDashed bool
Whether the edge should be drawn as a dashed line.
final
label String?
Optional text label for the edge.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceId String
The ID of the starting node.
final
targetId String
The ID of the ending node.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited