GraphNode class

Represents a node in the Graph.

Constructors

GraphNode({required String id, required String label, Color? color, Map<String, dynamic>? data})
const

Properties

color Color?
Optional custom color for this specific node.
final
data Map<String, dynamic>?
Optional extra data associated with the node.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for the node.
final
label String
Text displayed near the node.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited